using System;
using System.Collections;
using SoftwareFX.ChartFX.Lite;

using hsc.system;

namespace hsc.chart
{
	/// <summary>
	/// Contains information used to generate other types of HSC charts.
	/// </summary>
	public class OtherChartInfo
	{
		private String[] levelNames =
			{ "Ascension", "Beaver Creek", "Burial Mounds", "Coagulation",
			"Colossus", "Foundation", "Headlong", "Ivory Tower",
			"Lockout", "Midship", "Waterworks", "Zanzibar" };

		private String chartKind;
		private String playerName;

		/// <summary>Gets or sets the chart kind.</summary>
		/// <value>A String.</value>
		public String ChartKind
		{
			get
			{
				return chartKind;
			}

			set
			{
				chartKind = value;
			}
		}

		/// <summary>Gets the gallery type for this chart.</summary>
		/// <value>A Gallery.</value>
		public Gallery GalleryType
		{
			get
			{
				Gallery retVal = Gallery.Bar;

				return retVal;
			}
		}

		/// <summary>Gets or sets the player name.</summary>
		/// <value>A String.</value>
		public String PlayerName
		{
			get
			{
				return playerName;
			}

			set
			{
				playerName = value;
			}
		}

		/// <summary>
		/// Creates a new OtherChartInfo.
		/// </summary>
		public OtherChartInfo()
		{
		}

		/// <summary>
		/// Creates the game finishes chart data points.
		/// </summary>
		/// <returns>The data points.</returns>
		public int[] createFinishesPoints()
		{
			HSCPlayer player = HSCPlayers.Instance[playerName];
			int[] retVal = new int[5];

			foreach ( GameInfo gInfo in player.GameInfos )
			{
				if ( gInfo.PlayerPlace == 1 )
				{
					retVal[0] += 1;
				}
				else if ( gInfo.PlayerPlace == 2 )
				{
					retVal[1] += 1;
				}
				else if ( gInfo.PlayerPlace == 3 )
				{
					retVal[2] += 1;
				}
				else if ( gInfo.PlayerPlace == 4 )
				{
					retVal[3] += 1;
				}
				else
				{
					retVal[4] += 1;
				}
			}

			return retVal;
		}

		/// <summary>
		/// Creates data points for the 'who's good where?' chart.
		/// </summary>
		/// <returns>The data points.</returns>
		public double[][] createLevelPoints()
		{
			int numPlayers = HSCPlayers.Instance.Players.Count;
			int numLevels = levelNames.Length;
			int playerIndex = 0;
			int levelIndex = 0;

			double[][] retVal = new double[numPlayers][];

			foreach ( HSCPlayer player in HSCPlayers.Instance.Players )
			{
				retVal[playerIndex] = new double[numLevels];

				foreach ( String level in levelNames )
				{
					OrgChartInfo orgInfo = new OrgChartInfo();
					orgInfo.CategoryName = "Level";
					orgInfo.PlayerName = player.Name;
					orgInfo.StatName = "Avg Score";

					retVal[playerIndex][levelIndex] = orgInfo.getStatValue( level );

					levelIndex += 1;
				}

				playerIndex += 1;
				levelIndex = 0;
			}

			return retVal;
		}

		/// <summary>
		/// Returns a list of titles for chart data points.
		/// </summary>
		/// <returns>An array of Strings.</returns>
		public String[] getPointTitles()
		{
			String[] retVal = null;

			if ( chartKind.ToLower().Equals( "game finishes" ) )
			{
				retVal = new String[5];
				retVal[0] = "First Place";
				retVal[1] = "Second Place";
				retVal[2] = "Third Place";
				retVal[3] = "Fourth Place";
				retVal[4] = "Lower";
			}
			else if ( chartKind.ToLower().Equals( "who's good where?" ) )
			{
				retVal = levelNames;
			}

			return retVal;
		}

		/// <summary>
		/// Returns a list of series titles, if there are any.
		/// </summary>
		/// <returns>A list of series titles.</returns>
		public String[] getSeriesTitles()
		{
			String[] retVal = null;

			if ( chartKind.ToLower().Equals( "game finishes" ) )
			{
				retVal = new String[1];
				retVal[0] = playerName;
			}
			else if ( chartKind.ToLower().Equals( "who's good where?" ) )
			{
				ICollection players = HSCPlayers.Instance.Players;
				retVal = new String[players.Count];
				int i = 0;

				foreach ( HSCPlayer player in players )
				{
					retVal[i] = player.Name;
					i += 1;
				}
			}

			return retVal;
		}
	}
}
