using System;
using SoftwareFX.ChartFX.Lite;

using hsc.system;

namespace hsc.chart
{
	/// <summary>
	/// Contains the information needed to create a single stat chart.
	/// </summary>
	public class SingleStatChartInfo
	{
		private String statName;
		private String chartTypeName;

		/// <summary>Gets or sets the chart type name.</summary>
		/// <value>A String.</value>
		public String ChartTypeName
		{
			get
			{
				return chartTypeName;
			}

			set
			{
				chartTypeName = value;
			}
		}

		/// <summary>Gets the gallery chart type.</summary>
		/// <value>A Gallery.</value>
		public Gallery GalleryType
		{
			get
			{
				Gallery retVal = Gallery.Bar;

				if ( chartTypeName.ToLower().Equals( "bar" ) )
				{
					retVal = Gallery.Bar;
				}
				else if ( chartTypeName.ToLower().Equals( "pie" ) )
				{
					retVal = Gallery.Pie;
				}

				return retVal;
			}
		}

		/// <summary>Gets or sets the stat name.</summary>
		/// <value>A String.</value>
		public String StatName
		{
			get
			{
				return statName;
			}

			set
			{
				statName = value;
			}
		}

		/// <summary>
		/// Creates a new SingleStatChartInfo.
		/// </summary>
		public SingleStatChartInfo()
		{
		}

		/// <summary>
		/// Gets the value of a single player stat.
		/// </summary>
		/// <param name="player">The player in question.</param>
		/// <param name="stat">The desired stat.</param>
		/// <returns>The stat value.</returns>
		public double getStatValue( HSCPlayer player )
		{
			double retVal = 0;

			if ( statName.ToLower().Equals( "assists" ) )
			{
				retVal = player.TotalAssists;
			}
			else if ( statName.ToLower().Equals( "deaths" ) )
			{
				retVal = player.TotalDeaths;
			}
			else if ( statName.ToLower().Equals( "games" ) )
			{
				retVal = player.GameInfos.Count;
			}
			else if ( statName.ToLower().Equals( "kills" ) )
			{
				retVal = player.TotalKills;
			}
			else if ( statName.ToLower().Equals( "score" ) )
			{
				retVal = player.TotalScore;
			}
			else if ( statName.ToLower().Equals( "avg assists" ) )
			{
				retVal = player.AvgAssists;
			}
			else if ( statName.ToLower().Equals( "avg deaths" ) )
			{
				retVal = player.AvgDeaths;
			}
			else if ( statName.ToLower().Equals( "avg kills" ) )
			{
				retVal = player.AvgKills;
			}
			else if ( statName.ToLower().Equals( "avg score" ) )
			{
				retVal = player.AvgScore;
			}

			return retVal;
		}
	}
}
