using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace hsc.presentation
{
	/// <summary>
	/// Represents a dialog that allows the user to add a Halo2 player
	/// to the system.
	/// </summary>
	public class AddPlayerDialog : System.Windows.Forms.Form
	{
		#region Windows Form Designed generated state
		private System.Windows.Forms.Label nameLabel;
		private System.Windows.Forms.TextBox nameTextBox;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.TextBox rssTextField;
		private System.Windows.Forms.Label rssLabel;
		private System.Windows.Forms.LinkLabel helpLinkLabel;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		#endregion

		/// <summary>Gets or sets the Halo2RSS link text box text.</summary>
		/// <value>A string.</value>
		public String RSSLinkText
		{
			get
			{
				return rssTextField.Text;
			}

			set
			{
				rssTextField.Text = value;
			}
		}

		/// <summary>Gets or sets the name text box text.</summary>
		/// <value>A string.</value>
		public String NameText
		{
			get
			{
				return nameTextBox.Text;
			}

			set
			{
				nameTextBox.Text = value;
			}
		}

		/// <summary>
		/// Creates a new AddPlayerDialog.
		/// </summary>
		public AddPlayerDialog()
		{
			InitializeComponent();

			okButton.Click += new EventHandler( okButtonClicked );
			helpLinkLabel.LinkClicked += new LinkLabelLinkClickedEventHandler( helpLinkClicked );
		}

		/// <summary>
		/// Called when the help link label has been clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void helpLinkClicked( Object source, LinkLabelLinkClickedEventArgs e )
		{
			LinkHelpDialog helpDialog = new LinkHelpDialog();
			Point dialogLocation = PointToScreen( helpLinkLabel.Location );
			dialogLocation.X -= 50;
			dialogLocation.Y -= 20;

			helpDialog.Location = dialogLocation;
			helpDialog.Show();
		}

		/// <summary>
		/// Called when the OK button has been clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void okButtonClicked( Object source, EventArgs e )
		{
			this.DialogResult = DialogResult.OK;
			this.Close();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(AddPlayerDialog));
			this.nameLabel = new System.Windows.Forms.Label();
			this.nameTextBox = new System.Windows.Forms.TextBox();
			this.rssTextField = new System.Windows.Forms.TextBox();
			this.okButton = new System.Windows.Forms.Button();
			this.cancelButton = new System.Windows.Forms.Button();
			this.rssLabel = new System.Windows.Forms.Label();
			this.helpLinkLabel = new System.Windows.Forms.LinkLabel();
			this.SuspendLayout();
			// 
			// nameLabel
			// 
			this.nameLabel.Location = new System.Drawing.Point(8, 8);
			this.nameLabel.Name = "nameLabel";
			this.nameLabel.Size = new System.Drawing.Size(88, 20);
			this.nameLabel.TabIndex = 0;
			this.nameLabel.Text = "Player Name";
			this.nameLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// nameTextBox
			// 
			this.nameTextBox.Location = new System.Drawing.Point(104, 8);
			this.nameTextBox.Name = "nameTextBox";
			this.nameTextBox.Size = new System.Drawing.Size(176, 20);
			this.nameTextBox.TabIndex = 1;
			this.nameTextBox.Text = "";
			// 
			// rssTextField
			// 
			this.rssTextField.Location = new System.Drawing.Point(104, 32);
			this.rssTextField.Name = "rssTextField";
			this.rssTextField.Size = new System.Drawing.Size(176, 20);
			this.rssTextField.TabIndex = 2;
			this.rssTextField.Text = "";
			// 
			// okButton
			// 
			this.okButton.Location = new System.Drawing.Point(160, 88);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(56, 23);
			this.okButton.TabIndex = 4;
			this.okButton.Text = "OK";
			// 
			// cancelButton
			// 
			this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancelButton.Location = new System.Drawing.Point(224, 88);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(56, 23);
			this.cancelButton.TabIndex = 5;
			this.cancelButton.Text = "Cancel";
			// 
			// rssLabel
			// 
			this.rssLabel.Location = new System.Drawing.Point(8, 32);
			this.rssLabel.Name = "rssLabel";
			this.rssLabel.Size = new System.Drawing.Size(88, 20);
			this.rssLabel.TabIndex = 6;
			this.rssLabel.Text = "Halo2RSS URL";
			this.rssLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// helpLinkLabel
			// 
			this.helpLinkLabel.Location = new System.Drawing.Point(208, 56);
			this.helpLinkLabel.Name = "helpLinkLabel";
			this.helpLinkLabel.Size = new System.Drawing.Size(64, 23);
			this.helpLinkLabel.TabIndex = 7;
			this.helpLinkLabel.TabStop = true;
			this.helpLinkLabel.Text = "What URL?";
			this.helpLinkLabel.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// AddPlayerDialog
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.cancelButton;
			this.ClientSize = new System.Drawing.Size(290, 119);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.helpLinkLabel,
																		  this.rssLabel,
																		  this.cancelButton,
																		  this.okButton,
																		  this.rssTextField,
																		  this.nameTextBox,
																		  this.nameLabel});
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "AddPlayerDialog";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Add Halo2 Player";
			this.ResumeLayout(false);

		}
		#endregion

	}
}
