using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

using hsc.system;

namespace hsc.presentation
{
	/// <summary>
	/// Represents a dialog that can be used to remove HSC players from the system.
	/// </summary>
	public class SelectPlayersDialog : System.Windows.Forms.Form
	{
		#region Windows Form Designer generated state
		private System.Windows.Forms.Panel buttonPanel;
		private System.Windows.Forms.Button okButton;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.GroupBox listGroupBox;
		private System.Windows.Forms.CheckedListBox playerListBox;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		#endregion

		/// <summary>Gets the player list box.</summary>
		/// <value>A CheckedListBox.</value>
		public CheckedListBox PlayerListBox
		{
			get
			{
				return playerListBox;
			}
		}

		/// <summary>Gets or sets the list group box text.</summary>
		/// <value>A String.</value>
		public String GroupBoxText
		{
			get
			{
				return listGroupBox.Text;
			}

			set
			{
				listGroupBox.Text = value;
			}
		}

		/// <summary>
		/// Creates a new SelectPlayersDialog.
		/// </summary>
		public SelectPlayersDialog()
		{
			InitializeComponent();

			this.okButton.Click += new EventHandler( okButtonClicked );

			this.Load += new EventHandler( formLoaded );
		}

		/// <summary>
		/// Called before the dialog is shown for the first time.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void formLoaded( Object source, EventArgs e )
		{
			HSCPlayers players = HSCPlayers.Instance;
			
			foreach ( HSCPlayer player in players.Players )
			{
				playerListBox.Items.Add( player.Name, false );
			}
		}

		/// <summary>
		/// Called when the ok button is clicked.
		/// </summary>
		/// <param name="source">The source of the event.</param>
		/// <param name="e">The event's data.</param>
		private void okButtonClicked( Object source, EventArgs e )
		{
			this.DialogResult = DialogResult.OK;
			this.Close();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(SelectPlayersDialog));
			this.buttonPanel = new System.Windows.Forms.Panel();
			this.cancelButton = new System.Windows.Forms.Button();
			this.okButton = new System.Windows.Forms.Button();
			this.listGroupBox = new System.Windows.Forms.GroupBox();
			this.playerListBox = new System.Windows.Forms.CheckedListBox();
			this.buttonPanel.SuspendLayout();
			this.listGroupBox.SuspendLayout();
			this.SuspendLayout();
			// 
			// buttonPanel
			// 
			this.buttonPanel.Controls.AddRange(new System.Windows.Forms.Control[] {
																					  this.cancelButton,
																					  this.okButton});
			this.buttonPanel.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.buttonPanel.Location = new System.Drawing.Point(0, 143);
			this.buttonPanel.Name = "buttonPanel";
			this.buttonPanel.Size = new System.Drawing.Size(218, 40);
			this.buttonPanel.TabIndex = 0;
			// 
			// cancelButton
			// 
			this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancelButton.Location = new System.Drawing.Point(152, 8);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(56, 23);
			this.cancelButton.TabIndex = 1;
			this.cancelButton.Text = "Cancel";
			// 
			// okButton
			// 
			this.okButton.Location = new System.Drawing.Point(88, 8);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(56, 23);
			this.okButton.TabIndex = 0;
			this.okButton.Text = "OK";
			// 
			// listGroupBox
			// 
			this.listGroupBox.Controls.AddRange(new System.Windows.Forms.Control[] {
																					   this.playerListBox});
			this.listGroupBox.Dock = System.Windows.Forms.DockStyle.Fill;
			this.listGroupBox.Name = "listGroupBox";
			this.listGroupBox.Size = new System.Drawing.Size(218, 143);
			this.listGroupBox.TabIndex = 1;
			this.listGroupBox.TabStop = false;
			this.listGroupBox.Text = "Select Player(s)";
			// 
			// playerListBox
			// 
			this.playerListBox.Dock = System.Windows.Forms.DockStyle.Fill;
			this.playerListBox.Location = new System.Drawing.Point(3, 16);
			this.playerListBox.Name = "playerListBox";
			this.playerListBox.Size = new System.Drawing.Size(212, 124);
			this.playerListBox.TabIndex = 2;
			// 
			// RemovePlayerDialog
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.cancelButton;
			this.ClientSize = new System.Drawing.Size(218, 183);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.listGroupBox,
																		  this.buttonPanel});
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "RemovePlayerDialog";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Select Players";
			this.buttonPanel.ResumeLayout(false);
			this.listGroupBox.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	}
}
