using System;

namespace hsc.system
{
	/// <summary>
	/// Contains information about a Halo2 game.
	/// </summary>
	[Serializable]
	public class GameInfo
	{
		private String playList;
		private String level;
		private String playDate;
		private String gameLink;
        private String teamName;
		private int score;
		private int kills;
		private int deaths;
		private int assists;
		private int place;

		/// <summary>Gets or sets the number of assists.</summary>
		/// <value>An int.</value>
		public int Assists
		{
			get
			{
				return assists;
			}

			set
			{
				assists = value;
			}
		}

		/// <summary>Gets or sets the number of deaths.</summary>
		/// <value>An int.</value>
		public int Deaths
		{
			get
			{
				return deaths;
			}

			set
			{
				deaths = value;
			}
		}

		/// <summary>Gets or set the link to the Bungie.net game viewer.</summary>
		/// <value>A String.</value>
		public String GameLink
		{
			get
			{
				return gameLink;
			}

			set
			{
				gameLink = value;
			}
		}

		/// <summary>Gets or sets the number of kills.</summary>
		/// <value>An int.</value>
		public int Kills
		{
			get
			{
				return kills;
			}

			set
			{
				kills = value;
			}
		}

		/// <summary>Gets or sets the level name for this game.</summary>
		/// <value>A String.</value>
		public String Level
		{
			get
			{
				return level;
			}

			set
			{
				level = value;
			}
		}

		/// <summary>Gets or sets the player finish place.</summary>
		/// <value>An int.</value>
		public int PlayerPlace
		{
			get
			{
				return place;
			}

			set
			{
				place = value;
			}
		}

		/// <summary>Gets or sets the play date.</summary>
		/// <value>A String.</value>
		public DateTime PlayDate
		{
			get
			{
				return DateTime.Parse( playDate );
			}

			set
			{
				playDate = value.ToString();
			}
		}

		/// <summary>Gets or sets the playlist for this game.</summary>
		/// <value>A String.</value>
		public String PlayList
		{
			get
			{
				return playList;
			}

			set
			{
				playList = value;
			}
		}

		/// <summary>Gets or sets the score.</summary>
		/// <value>An int.</value>
		public int Score
		{
			get
			{
				return score;
			}

			set
			{
				score = value;
			}
		}

		/// <summary>Gets or sets the team name.</summary>
		/// <value>A string.</value>
		public String TeamName
		{
			get
			{
				return teamName;
			}

			set
			{
				teamName = value;
			}
		}

		/// <summary>
		/// Creates a new GameInfo.
		/// </summary>
		public GameInfo()
		{
		}
	}
}
