using System;
using System.Collections;

using hsc.system;

namespace hsc.system
{
	/// <summary>
	/// Compares HSC players as part of computing their RoboRank (tm).
	/// </summary>
	public class RoboRankComparer : IComparer
	{
        public const int COMPARE_AVG_ASSISTS = 0;
        public const int COMPARE_AVG_KILLS = 1;
        public const int COMPARE_AVG_DEATHS = 2;

        private int dataToCompare;

        /// <summary>Gets which data is being compared.</summary>
        /// <value>An int.</value>
        public int CompareData
        {
            get
            {
                return dataToCompare;
            }
        }

		/// <summary>
		/// Creates a new RoboRankComparer.
		/// </summary>
        /// <param name="data">The data to compare, must be one of the
        /// COMPARE_* constants.</param>
		public RoboRankComparer( int data )
		{
            if ( data != COMPARE_AVG_KILLS && data != COMPARE_AVG_DEATHS && data != COMPARE_AVG_ASSISTS )
            {
                throw new ArgumentException( "Invalid compare data." );
            }

            dataToCompare = data;
		}

		/// <summary>
		/// Compares two objects.
		/// </summary>
		/// <param name="x">The first object.</param>
		/// <param name="y">The second object.</param>
		/// <returns>Less and zero if x less than y, zero if z equals y,
		/// greater than zero if x is greater than y.</returns>
		public int Compare( Object x, Object y )
		{
			if ( !( x is HSCPlayer && y is HSCPlayer ) )
			{
				throw new ArgumentException( "x and y must be HSCPlayer objects." );
			}

			HSCPlayer playerX = (HSCPlayer)x;
			HSCPlayer playerY = (HSCPlayer)y;

            int retVal = 0;

            if ( dataToCompare == COMPARE_AVG_ASSISTS )
            {
                retVal = playerY.AvgAssists.CompareTo( playerX.AvgAssists );
            }
            else if ( dataToCompare == COMPARE_AVG_KILLS )
            {
                retVal = playerY.AvgKills.CompareTo( playerX.AvgKills );
            }
            else if ( dataToCompare == COMPARE_AVG_DEATHS )
            {
                retVal = playerY.AvgDeaths.CompareTo( playerX.AvgDeaths );
            }

			return retVal;
		}
	}
}
