using System;
using System.Collections;
using System.Threading;

using hsc.presentation;

namespace hsc.system
{
	/// <summary>
	/// Summary description for StatUpdateThread.
	/// </summary>
	public class StatUpdateThread
	{
		private bool stopped;

		/// <summary>Gets whether the thread is stopped.</summary>
		/// <value>A bool.</value>
		public bool IsStopped
		{
			get
			{
				return stopped;
			}
		}

		/// <summary>Gets a ThreadStart delegate for running the thread.</summary>
		/// <value>A ThreadStart.</value>
		public ThreadStart ThreadStartDelegate
		{
			get
			{
				return new ThreadStart( run );
			}
		}

		/// <summary>
		/// Creates a new StatUpdateThread.
		/// </summary>
		public StatUpdateThread()
		{
			stopped = false;
		}

		/// <summary>
		/// Indicates that this thread should stop running.
		/// </summary>
		public void stopThread()
		{
			stopped = true;
		}

		/// <summary>
		/// Called when this thread should start running.
		/// </summary>
		private void run()
		{
			stopped = false;
			HSCForm hscForm = HSCMain.HscForm;
			hscForm.MenuBarEnabled = false;

			ICollection players = HSCPlayers.Instance.Players;

            try
            {
                foreach ( HSCPlayer player in players )
                {
                    hscForm.StatusBarText = "Compiling Stats for: " + player.Name;

                    player.compileStats();

                    if ( stopped )
                    {
                        break;
                    }
                }

                hscForm.MenuBarEnabled = true;
                hscForm.StatusBarText = "Halo2 Stat Collector";

                hscForm.updateView();
            }
            catch ( InvalidOperationException )
            {
                Environment.Exit( -1 );
            }

			HSCPlayers hscPlayers = HSCPlayers.Instance;

			if ( !hscPlayers.CurrentArchivePath.Equals( "" ) )
			{
				hscPlayers.saveStatArchive( hscPlayers.CurrentArchivePath );
			}
		}
	}
}
